@@ -9,8 +9,8 @@ def SearchWidget(query, ward):
     return WidgetInput(kind="SearchWidget", query=query, ward=ward)
 
 
-def ImageReturnWidget(query=""):
-    return ReturnWidgetInput(kind="ImageReturnWidget", query=query)
+def ImageReturnWidget(query, ward):
+    return ReturnWidgetInput(kind="ImageReturnWidget", query=query, ward=ward)
 
 
 def StringWidget(as_paragraph=False):
@@ -21,5 +21,5 @@ def CustomWidget(hook: str):
     return WidgetInput(kind="CustomWidget", hook=hook)
 
 
-def CustomReturnWidget(hook: str):
-    return ReturnWidgetInput(kind="CustomReturnWidget", hook=hook)
+def CustomReturnWidget(hook: str, ward: str):
+    return ReturnWidgetInput(kind="CustomReturnWidget", hook=hook, ward=ward)
